def ScaleTransform(data=None, object=None, accumulate=None, **generic_arguments):
    """
    DESCRIPTION:
        ScaleTransform() function scales specified columns in input data, using ScaleFit() function output.

    PARAMETERS:
        data:
            Required Argument.
            Specifies the input teradataml DataFrame.
            Types: teradataml DataFrame

        object:
            Required Argument.
            Specifies the teradataml DataFrame containing the output of generated by
            ScaleFit() function or the instance of ScaleFit.
            Types: teradataml DataFrame or ScaleFit

        accumulate:
            Optional Argument.
            Specifies the names of input teradataml DataFrame columns to copy to the output.
            Types: str OR list of Strings (str)

        **generic_arguments:
            Specifies the generic keyword arguments SQLE functions accept.
            Below are the generic keyword arguments:
                persist:
                    Optional Argument.
                    Specifies whether to persist the results of the function in a table or not.
                    When set to True, results are persisted in a table; otherwise, results
                    are garbage collected at the end of the session.
                    Default Value: False
                    Types: boolean

                volatile:
                    Optional Argument.
                    Specifies whether to put the results of the function in a volatile table or not.
                    When set to True, results are stored in a volatile table, otherwise not.
                    Default Value: False
                    Types: boolean

            Function allows the user to partition, hash, order or local order the input
            data. These generic arguments are available for each argument that accepts
            teradataml DataFrame as input and can be accessed as:
                * "<input_data_arg_name>_partition_column" accepts str or list of str (Strings)
                * "<input_data_arg_name>_hash_column" accepts str or list of str (Strings)
                * "<input_data_arg_name>_order_column" accepts str or list of str (Strings)
                * "local_order_<input_data_arg_name>" accepts boolean
            Note:
                These generic arguments are supported by teradataml if the underlying
                SQL Engine function supports, else an exception is raised.

    RETURNS:
        Instance of ScaleTransform.
        Output teradataml DataFrames can be accessed using attribute
        references, such as ScaleTransformObj.<attribute_name>.
        Output teradataml DataFrame attribute name is:
            result

    RAISES:
        TeradataMlException, TypeError, ValueError

    EXAMPLE:
        # Notes:
        #    1. Get the connection to Vantage, before importing the function in user space.
        #    2. User can import the function, if it is available on the Vantage user is connected to.
        #    3. To check the list of analytic functions available on the Vantage user connected to,
        #       use "display_analytic_functions()".

        # Load the example data.
        load_example_data("teradataml", ["scale_housing"])

        # Create teradataml DataFrame.
        scaling_house = DataFrame.from_table("scale_housing")

        # Check the list of available analytic functions.
        display_analytic_functions()

        # Import functions ScaleFit and ScaleTransform.
        from teradataml import ScaleFit, ScaleTransform

        # Example 1: Scale "lotsize" with respect to mean value of the column.
        fit_obj = ScaleFit(data=scaling_house,
                           target_columns="lotsize",
                           scale_method="MEAN",
                           miss_value="KEEP",
                           global_scale=False,
                           multiplier="1",
                           intercept="0")

        # Print the result DataFrame.
        print(fit_obj.output)

        # Scale "lotsize" column.
        obj = ScaleTransform(data=scaling_house,
                             object=fit_obj.output,
                             accumulate="price")

        # Print the result DataFrame.
        print(obj.result)
    """
